@@ -1,11 +1,12 @@
 BarChart <-
-function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"), 
+function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"), 
 
          fill=getOption("fill.bar"),
          stroke=getOption("stroke.bar"),
          bg=getOption("bg"),
          grid=getOption("grid"),
          box=getOption("box"),
+         trans=NULL,
 
          colors=c("rainbow", "terrain", "heat"),
 
@@ -14,9 +15,9 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
          
          xlab=NULL, ylab=NULL, main=NULL,
          cex.axis=0.75, axes="gray30",
-         value.labels=NULL, label.max=20, rotate.values=0, offset=0.5,
+         value.labels=NULL, label.max=20, rotate.x=0, rotate.y=0, offset=0.5,
 
-         beside=FALSE, low.color=NULL, hi.color=NULL, count.labels=NULL,
+         beside=FALSE, low.fill=NULL, hi.fill=NULL, 
 
          legend.title=NULL, legend.loc="right.margin", legend.labels=NULL,
          legend.horiz=FALSE, 
@@ -46,19 +47,31 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
   dots <- list(...)  # check for deprecated/changed parameters
   if (length(dots) > 0) {
     for (i in 1:length(dots)) {
-      old.nm <- c("col.fill", "col.stroke", "col.bg", "col.grid", "col.box",
-                  "col.reg", "col.axis", "col.trans", "col.low", "col.hi")
-      if (names(dots)[i] %in% old.nm) {
+      if (grepl("color.", names(dots)[i], fixed=TRUE)) {
         cat("\n"); stop(call.=FALSE, "\n","------\n",
-          "options that began with the abbreviation  col  now begin with  ",
-          "color \n\n")
-        }
+          "color options dropped the  color. prefix\n",
+          "eg., fill, instead of color.fill\n\n")
+      }
+      if (grepl("col.", names(dots)[i], fixed=TRUE)) 
+        if (names(dots)[i] != "col.main"  &&
+            names(dots)[i] != "col.lab"  &&
+            names(dots)[i] != "col.sub") {
+          cat("\n"); stop(call.=FALSE, "\n","------\n",
+            "color options dropped the  col. prefix\n",
+            "eg., fill, instead of col.fill\n\n")
+      }
       if (names(dots)[i] == "addtop") 
         cat("\naddtop  is now a multiplicative factor instead of additive\n\n")
       if (names(dots)[i] == "count.levels") {
         cat("\n"); stop(call.=FALSE, "\n","------\n",
           "Now use  count.labels  instead of count.levels\n\n")
       }
+      if (names(dots)[i] == "count.labels") {
+        cat("\n"); stop(call.=FALSE, "\n","------\n",
+          "count.labels  not available, but now specify a y-variable for\n",
+          "the data values to obtain the same effect, which can be\n",
+          " continuous, and a categorical variable for the labels\n\n")
+      }
       if (grepl("color.", names(dots)[i], fixed=TRUE)) {
         cat("\n"); stop(call.=FALSE, "\n","------\n",
           "color options dropped the  color. prefix\n",
@@ -100,9 +113,9 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
         if (exists(x.name, where=.GlobalEnv)) if (is.matrix(x)) { 
           x.name <- xlab
           xlab <- NULL
-          y.name <- legend.title
+          by.name <- legend.title
           options(xname = x.name)
-          options(yname = y.name)
+          options(byname = by.name)
         }
         x.call <- x
         if (is.function(x.call)) x.call <- eval(substitute(data$x))
@@ -117,8 +130,8 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     if (!missing(by)) {
 
       # get actual variable name before potential call of data$x
-      y.name <- deparse(substitute(by)) 
-      options(yname = y.name)
+      by.name <- deparse(substitute(by)) 
+      options(byname = by.name)
 
       # see if y exists from a function call
       # indicate a function call with sys.nframe returns larger than 1 
@@ -127,22 +140,47 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
       # get conditions and check for data existing
       #if (!in.call) {
-        xs <- .xstatus(y.name, df.name, quiet)
+        xs <- .xstatus(by.name, df.name, quiet)
         in.global <- xs$ig 
       #}
       #else in.global <- FALSE
       # if y is in global, sys.nframe() returns two, in.call is TRUE,
       #   which leads to in.global FALSE
-      #if (exists(y.name, where=.GlobalEnv)) in.global <- TRUE
+      #if (exists(by.name, where=.GlobalEnv)) in.global <- TRUE
+
+      # see if var exists in data frame, if x not in Global Env or function call 
+      if (!in.global) .xcheck(by.name, df.name, data)
+      #if (!in.global && !in.call) .xcheck(by.name, df.name, data)
+      if (!in.global)
+        by.call <- eval(substitute(data$by))
+      else {  # vars that are function names get assigned to global
+        by.call <- by
+        if (is.function(by.call)) by.call <- eval(substitute(data$by))
+      }
+
+    }
+    else
+      by.call <- NULL
+
+
+    # evaluate y
+    if (!missing(y)) {
+
+      # get actual variable name before potential call of data$x
+      y.name <- deparse(substitute(y)) 
+      options(yname = y.name)
+
+      # get conditions and check for data existing
+        xs <- .xstatus(y.name, df.name, quiet)
+        in.global <- xs$ig 
 
       # see if var exists in data frame, if x not in Global Env or function call 
       if (!in.global) .xcheck(y.name, df.name, data)
-      #if (!in.global && !in.call) .xcheck(y.name, df.name, data)
       if (!in.global)
-        y.call <- eval(substitute(data$by))
+        y.call <- eval(substitute(data$y))
       else {  # vars that are function names get assigned to global
-        y.call <- by
-        if (is.function(y.call)) y.call <- eval(substitute(data$by))
+        y.call <- y
+        if (is.function(y.call)) y.call <- eval(substitute(data$y))
       }
 
     }
@@ -150,38 +188,6 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       y.call <- NULL
 
 
-    # evaluate count.labels
-    #---------------------
-    if (!missing(count.labels)) {
-
-      # get actual variable name before potential call of data$x
-      x.name <- deparse(substitute(count.labels)) 
-      options(xname = x.name)
-
-      # get conditions and check for data existing
-      xs <- .xstatus(x.name, df.name, quiet)
-      in.global <- xs$ig 
-
-      # see if var exists in data frame, if x not in Global Env or function call 
-      if (!missing(x) && !in.global)
-        .xcheck(x.name, df.name, data)
-
-      if (!in.global) count.labels.call <- eval(substitute(data$count.labels))
-      else {  # vars that are function names get assigned to global
-        count.labels.call <- count.labels
-        if (is.function(count.labels.call)) 
-          count.labels.call <- eval(substitute(data$count.labels))
-      }
- 
-      #if (!.is.integer(x.call)) { 
-      #cat("\n"); stop(call.=FALSE, "\n","------\n",
-        #"Values to be analyzed must be counts, that is, integers\n",
-        #"First two values to analyze: ", x.call[1], " ", x.call[2], "\n\n")
-      #}
-    }
-    else
-      count.labels.call <- NULL
-
     if (length(unique(na.omit(x.call))) == 1) { 
       cat("\n"); stop(call.=FALSE, "\n","------\n",
         "There is only one unique value for the values of ", x.name,
@@ -201,12 +207,11 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     orig.params <- par(no.readonly=TRUE)
     on.exit(par(orig.params))
 
-    bc <- .bc.main(x.call, y.call,
-         fill, stroke, bg, grid, box, colors,
+    bc <- .bc.main(x.call, y.call, by.call,
+         fill, stroke, bg, grid, box, trans, colors,
          horiz, over.grid, addtop, gap, proportion, xlab, ylab, main,
          value.labels, label.max,
-         cex.axis, axes, rotate.values, offset, beside, low.color, hi.color,
-         count.labels.call,
+         cex.axis, axes, rotate.x, rotate.y, offset, beside, low.fill, hi.fill,
          legend.title, legend.loc, legend.labels, legend.horiz, quiet, ...)
 
     if (is.null(pdf)) {
@@ -220,11 +225,10 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
   else
     bc.data.frame(data, n.cat,
-      fill, stroke, bg, grid, box, colors,
+      fill, stroke, bg, grid, box, trans, colors,
       horiz, over.grid, addtop, gap, proportion, xlab, ylab, main,
       value.labels, label.max,
-      cex.axis, axes, rotate.values, offset, beside, low.color, hi.color,
-      count.labels,
+      cex.axis, axes, rotate.x, rotate.y, offset, beside, low.fill, hi.fill,
       legend.title, legend.loc, legend.labels, legend.horiz, quiet,
       width, height, pdf, ...)
 
