@@ -105,7 +105,8 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
     if (num.cat || is.character(x.call)) {
       x.call <- as.factor(x.call)
-      .ncat("summary statistics", x.name, nu, n.cat)
+
+     .ncat("summary statistics", x.name, nu, n.cat)
     }
   }
 
@@ -122,13 +123,16 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
   # ordered factors have two attributes, "ordered" and "factor"
   else if (is.factor(x.call)) {
 
-    gl <- .getlabels(xlab=NULL, ylab=NULL, main=NULL, cex.lab=NULL)
+    gl <- .getlabels(xlab=NULL, ylab=NULL, main=NULL, cex.lab=NULL,
+                     graph.win=FALSE)
     x.name <- gl$xn; x.lab <- gl$xb; x.lbl <- gl$xl
     y.name <- gl$yn; y.lab <- gl$yb; y.lbl <- gl$yl
 
     if (is.factor(x.call)) 
+{
       stuff <- .ss.factor(x.call, y.call, brief, digits.d,
-                        x.name, y.name, x.lbl, y.lbl, label.max, ...) 
+                        x.name, y.name, x.lbl, y.lbl, label.max, ...)
+} 
     else if (is.character(x.call))
       if (nlevels(factor(x.call)) < length(x.call)) { 
         stuff <- .ss.factor(factor(x.call), by, brief, digits.d=NULL,
