@@ -49,7 +49,7 @@ function (x=mycor,
          col.fill=getOption("fill.pt"),
          shape.pts=21, col.grid=getOption("col.grid"),
          col.bg=getOption("bg"),
-         cex.axis=.85, col.axis="gray30", rotate.values=0, offset=0.5,
+         cex.axis=.85, col.axis="gray30", rotate.x=0, rotate.y=0, offset=0.5,
          xy.ticks=TRUE, line.width=1.1,
          xlab=NULL, ylab="Eigenvalues", main=main, sub=NULL, cex=NULL,
          x.start=NULL, x.end=NULL, y.start=NULL, y.end=NULL,
@@ -84,7 +84,7 @@ function (x=mycor,
          col.fill=getOption("fill.pt"),
          shape.pts=21, col.grid=getOption("grid"),
          col.bg=getOption("bg"),
-         cex.axis=.85, col.axis="gray30", rotate.values=0, offset=0.5,
+         cex.axis=.85, col.axis="gray30", rotate.x=0, rotate.y=0, offset=0.5,
          xy.ticks=TRUE, line.width=1.1,
          xlab=NULL, ylab="Differences of Successive Eigenvalues",
          main=main, sub=NULL, cex=NULL,
