@@ -1,7 +1,8 @@
 # plot legend for by variables
 
 .plt.by.legend <-
-function(mylevels, stroke, fill, shp, trans.pts, col.bg, usr) {
+function(mylevels, stroke, fill, shp, trans.pts, col.bg, usr,
+         pt.size=1.1, pt.lwd=0.5) {
 
   par(xpd=NA)  # allow drawing outside of plot region
 
@@ -21,8 +22,8 @@ function(mylevels, stroke, fill, shp, trans.pts, col.bg, usr) {
     #if (nchar(legend.title) > nchar(legend.labels[max.width][1]))
       #legend.title <- paste(" ", legend.title, " ", sep="") 
   #}
-  ll <- legend(0,0, legend=legend.labels, title=legend.title, cex=.7, pt.cex=1.1,
-            plot=FALSE)
+  ll <- legend(0,0, legend=legend.labels, title=legend.title, cex=.7,
+               pt.cex=pt.size, pt.lwd=pt.lwd, plot=FALSE)
 
   size <- (par("cxy")/par("cin"))  # 1 inch in user coordinates 
 
@@ -44,9 +45,11 @@ function(mylevels, stroke, fill, shp, trans.pts, col.bg, usr) {
   the.clr <- ifelse(grepl(".black", getOption("colors")), "gray90", "black")
 
   yi <- ifelse (options("device") == "RStudioGD", 1.4, 1)
+  # fill=length(legend.labels):1  puts the legend labels in the correct
+  #   order, but only for inflexible boxes that cannot be resized with pt.cex
   legend(xleft, ytop, legend=legend.labels, title=legend.title, 
-         pch=shp, horiz=FALSE, cex=.7, pt.cex=1.1, pt.lwd=0.5, box.lwd=.5, 
-         box.col="gray30", bg=col.bg, col=stroke, pt.bg=fill,
+         pch=shp, horiz=FALSE, cex=.7, pt.cex=pt.size, pt.lwd=pt.lwd,
+         box.lwd=.5, box.col="gray30", bg=col.bg, col=stroke, pt.bg=fill,
          text.col=the.clr, y.intersp=yi)
 
   par(xpd=FALSE)  # cancel drawing outside of plot region (need for RStudio)
