@@ -184,7 +184,7 @@ function(Y, Ynm, mu0=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
         col.stroke=getOption("stroke.pt"), 
         col.fill=getOption("fill.bar"), shape.pts=21,
         col.grid=getOption("grid"), col.bg=getOption("bg"),
-        cex.axis=0.75, col.axis="gray30", rotate.values=0, offset=.5,
+        cex.axis=0.75, col.axis="gray30", rotate.x=0, rotate.y=0, offset=.5,
         xy.ticks=TRUE, line.width=1.1,
         xlab=NULL, ylab=NULL, main=plt.title[plt.i], sub=NULL, cex=NULL,
         time.start=NULL, time.by=NULL, time.reverse=FALSE,
