@@ -352,7 +352,7 @@ function(YA, YB, n1, n2, m1, m2, s1, s2, from.data,
         col.stroke=getOption("stroke.pt"), 
         col.fill=getOption("fill.bar"), shape.pts=21,
         col.grid=getOption("grid"), col.bg=getOption("bg"),
-        cex.axis=0.75, col.axis="gray30", rotate.values=0, offset=.5,
+        cex.axis=0.75, col.axis="gray30", rotate.x=0, rotate.y=0, offset=.5,
         xy.ticks=TRUE, line.width=1.1,
         xlab=NULL, ylab=paste(Ynm,": ",X1nm, sep=""),
         main=plt.title[plt.i], sub=NULL,
@@ -377,7 +377,7 @@ function(YA, YB, n1, n2, m1, m2, s1, s2, from.data,
        col.stroke=getOption("stroke.pt"), 
        col.fill=getOption("fill.bar"), shape.pts=21,
        col.grid=getOption("grid"), col.bg=getOption("bg"),
-       cex.axis=0.85, col.axis="gray30", rotate.values=0, offset=.5,
+       cex.axis=0.85, col.axis="gray30", rotate.x=0, rotate.y=0, offset=.5,
        xy.ticks=TRUE, line.width=1.1,
        xlab=NULL, ylab=paste(Ynm,": ",X2nm, sep=""),
        main=plt.title[plt.i], sub=NULL,
